==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ClusterRoleBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterRoleBuilder extends io.fabric8.openshift.api.model.ClusterRoleFluentImpl<io.fabric8.openshift.api.model.ClusterRoleBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ClusterRole,io.fabric8.openshift.api.model.ClusterRoleBuilder>{
  public ClusterRoleBuilder() {
    this(false);
  }
  public ClusterRoleBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterRole(), validationEnabled);
  }
  public ClusterRoleBuilder(io.fabric8.openshift.api.model.ClusterRoleFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterRoleBuilder(io.fabric8.openshift.api.model.ClusterRoleFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterRole(), validationEnabled);
  }
  public ClusterRoleBuilder(io.fabric8.openshift.api.model.ClusterRoleFluent<?> fluent,io.fabric8.openshift.api.model.ClusterRole instance) {
    this(fluent, instance, false);
  }
  public ClusterRoleBuilder(io.fabric8.openshift.api.model.ClusterRoleFluent<?> fluent,io.fabric8.openshift.api.model.ClusterRole instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAggregationRule(instance.getAggregationRule()); 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withRules(instance.getRules()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterRoleBuilder(io.fabric8.openshift.api.model.ClusterRole instance) {
    this(instance,false);
  }
  public ClusterRoleBuilder(io.fabric8.openshift.api.model.ClusterRole instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAggregationRule(instance.getAggregationRule()); 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withRules(instance.getRules()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ClusterRoleFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ClusterRole build() {
    ClusterRole buildable = new ClusterRole(fluent.getAggregationRule(),fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getRules());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterRoleBuilder that = (ClusterRoleBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.6.1-sources.jar: io/fabric8/openshift/api/model/ClusterRoleBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterRoleBuilder extends ClusterRoleFluentImpl<ClusterRoleBuilder> implements VisitableBuilder<ClusterRole,ClusterRoleBuilder>{
  public ClusterRoleBuilder() {
    this(false);
  }
  public ClusterRoleBuilder(Boolean validationEnabled) {
    this(new ClusterRole(), validationEnabled);
  }
  public ClusterRoleBuilder(ClusterRoleFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterRoleBuilder(ClusterRoleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterRole(), validationEnabled);
  }
  public ClusterRoleBuilder(ClusterRoleFluent<?> fluent,ClusterRole instance) {
    this(fluent, instance, false);
  }
  public ClusterRoleBuilder(ClusterRoleFluent<?> fluent,ClusterRole instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAggregationRule(instance.getAggregationRule()); 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withRules(instance.getRules()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterRoleBuilder(ClusterRole instance) {
    this(instance,false);
  }
  public ClusterRoleBuilder(ClusterRole instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAggregationRule(instance.getAggregationRule()); 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withRules(instance.getRules()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ClusterRoleFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterRole build() {
    ClusterRole buildable = new ClusterRole(fluent.getAggregationRule(),fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getRules());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
